( cd usr/share/doc/HTML/ja/tavia ; rm -rf common )
( cd usr/share/doc/HTML/ja/tavia ; ln -sf /usr/share/doc/HTML/ja/common common )
( cd usr/share/doc/HTML/en/tavia ; rm -rf common )
( cd usr/share/doc/HTML/en/tavia ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/lib ; rm -rf libtaviasidebar.so )
( cd usr/lib ; ln -sf libtaviasidebar.so.0.0.0 libtaviasidebar.so )
( cd usr/lib ; rm -rf libtaviasidebar.so.0 )
( cd usr/lib ; ln -sf libtaviasidebar.so.0.0.0 libtaviasidebar.so.0 )
