<!DOCTYPE kpartgui SYSTEM "kpartgui.dtd">
<kpartgui name="tavia" version="1">
<MenuBar>
  <Menu name="file"><text>&amp;File</text>
    <Separator/>
  </Menu>
  <Menu name="edit"><text>&amp;Edit</text>
      <Action name="cut" />
      <Action name="copy" />
      <Action name="paste" />
      <Action name="rename" />
      <Action name="trash" />
      <Action name="del" />
    <Separator/>
  </Menu>
  <Menu name="view"><text>&amp;View</text>
    <Action name="fullScreenToggle" />
    <Separator/>
  </Menu>
  <Menu name="go_web"><text>&amp;Go</text>
    <Separator/>
  </Menu>
  <Menu name="settings" noMerge="1"><text>&amp;Settings</text>
    <Merge name="StandardToolBarMenuHandler" />
    <Action name="buttonColorSetting" />
    <Separator/>
  </Menu>
  <Menu name="tools"><text>&amp;Tool</text>
    <Separator/>
  </Menu>
  <Menu name="help"><text>&amp;Help</text>
    <Separator/>
  </Menu>
</MenuBar>
<ToolBar name="viewToolbar">
    <Action name="dock" />
    <Action name="mdiMenu" />
</ToolBar>
</kpartgui>
