<!DOCTYPE kpartgui SYSTEM "kpartgui.dtd">
<kpartgui name="taviatab" version="1">
<MenuBar>
  <Menu name="file"><text>&amp;File</text>
    <Separator/>
  </Menu>
  <Menu name="edit"><text>&amp;Edit</text>
    <Separator/>
  </Menu>
  <Menu name="view"><text>&amp;View</text>
    <Action name="addNewView" />
   <Separator/>
  </Menu>
  <Menu name="go_web"><text>&amp;Go</text>
    <Action name="urlBarSetForcus" />
    <Separator/>
    <Action name="viewLock" />
    <Separator/>
  </Menu>
</MenuBar>
<ToolBar name="viewToolbar">
    <Action name="addNewView" />
    <Separator/>
</ToolBar>

</kpartgui>
